==> ukui-greeter_1.2.5.orig.tar.gz: ukui-greeter/ukui-greeter/translations/fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>BioAuthentication</name>
    <message>
        <source>authentication failed, restart after 2 seconds</source>
        <translation type="obsolete">L&apos;authentification a échoué, redémarrez après 2 secondes</translation>
    </message>
</context>
<context>
    <name>BioDeviceView</name>
    <message>
        <source>password login</source>
        <translation type="obsolete">mot de passe</translation>
    </message>
    <message>
        <source>fingerprint</source>
        <translation type="obsolete">les empreintes digitales</translation>
    </message>
    <message>
        <source>fingerevin</source>
        <translation type="obsolete">doigt evin</translation>
    </message>
    <message>
        <source>iris</source>
        <translation type="obsolete">iris</translation>
    </message>
</context>
<context>
    <name>BiometricAuthWidget</name>
    <message>
        <source>Current device: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Identify failed, Please retry.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BiometricDevicesWidget</name>
    <message>
        <source>Please select the biometric device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Device type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Device name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeviceType</name>
    <message>
        <source>FingerPrint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FingerVein</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Iris</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Face</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>VoicePrint</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FakeDialog</name>
    <message>
        <source>cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GreeterWindow</name>
    <message>
        <source>CN</source>
        <translation type="obsolete">CN</translation>
    </message>
    <message>
        <source>EN</source>
        <translation type="obsolete">EN</translation>
    </message>
</context>
<context>
    <name>GreeterWrapper</name>
    <message>
        <source>failed to start session.</source>
        <translation>impossible de démarrer la session.</translation>
    </message>
</context>
<context>
    <name>IconEdit</name>
    <message>
        <source>Login</source>
        <translation type="obsolete">S&apos;identifier</translation>
    </message>
</context>
<context>
    <name>KeyboardWidget</name>
    <message>
        <source>KeyboardWidget</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LoginWindow</name>
    <message>
        <source>Login</source>
        <translation>S&apos;identifier</translation>
    </message>
    <message>
        <source>logged in</source>
        <translation>connecté</translation>
    </message>
    <message>
        <source>login</source>
        <translation>s&apos;identifier</translation>
    </message>
    <message>
        <source>Password: </source>
        <translation>Mot de passe: </translation>
    </message>
    <message>
        <source>login:</source>
        <translation>s&apos;identifier:</translation>
    </message>
    <message>
        <source>Incorrect password, please input again</source>
        <translation type="unfinished">Mot de passe incorrect, veuillez saisir à nouveau</translation>
    </message>
    <message>
        <source>please select the type of authentication</source>
        <translation type="obsolete">veuillez sélectionner le type d&apos;authentification</translation>
    </message>
    <message>
        <source>Incorrect user name, please input again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Retry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Biometric Authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password Authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other Devices</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>MainWindow</source>
        <translation type="unfinished">Fenêtre principale</translation>
    </message>
</context>
<context>
    <name>PowerWindow</name>
    <message>
        <source>Goodbye. Would you like to…</source>
        <translation type="obsolete">Au revoir. Voudriez-vous…</translation>
    </message>
    <message>
        <source>Other users are currently logged in to this computer, shutting down now will also close these other sessions.</source>
        <translation>D&apos;autres utilisateurs sont actuellement connectés à cet ordinateur, leur fermeture ferme également ces autres sessions.</translation>
    </message>
    <message>
        <source>suspend</source>
        <translation>suspendre</translation>
    </message>
    <message>
        <source>hibernate</source>
        <translation>hiberner</translation>
    </message>
    <message>
        <source>restart</source>
        <translation>redémarrer</translation>
    </message>
    <message>
        <source>shutdown</source>
        <translation>fermer</translation>
    </message>
    <message>
        <source>Goodbye. Would you like to...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SessionWindow</name>
    <message>
        <source>select the desktop environment</source>
        <translation type="obsolete">sélectionner l&apos;environnement de bureau</translation>
    </message>
    <message>
        <source> (Default)</source>
        <translation type="vanished"> (Défaut)</translation>
    </message>
</context>
<context>
    <name>UserEntry</name>
    <message>
        <source>logged in</source>
        <translation type="vanished">connecté</translation>
    </message>
</context>
<context>
    <name>UsersModel</name>
    <message>
        <source>Guest Session</source>
        <translation>Session d&apos;invité</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>S&apos;identifier</translation>
    </message>
    <message>
        <source>Guest</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> ukui-greeter_3.0.1.orig.tar.gz: ukui-greeter/ukui-greeter/translations/fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>BioAuthentication</name>
    <message>
        <source>authentication failed, restart after 2 seconds</source>
        <translation type="obsolete">L&apos;authentification a échoué, redémarrez après 2 secondes</translation>
    </message>
</context>
<context>
    <name>BioDeviceView</name>
    <message>
        <source>password login</source>
        <translation type="obsolete">mot de passe</translation>
    </message>
    <message>
        <source>fingerprint</source>
        <translation type="obsolete">les empreintes digitales</translation>
    </message>
    <message>
        <source>fingerevin</source>
        <translation type="obsolete">doigt evin</translation>
    </message>
    <message>
        <source>iris</source>
        <translation type="obsolete">iris</translation>
    </message>
</context>
<context>
    <name>BiometricAuthWidget</name>
    <message>
        <source>Current device: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Identify failed, Please retry.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BiometricDevicesWidget</name>
    <message>
        <source>Please select the biometric device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Device type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Device name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeviceType</name>
    <message>
        <source>FingerPrint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FingerVein</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Iris</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Face</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>VoicePrint</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FakeDialog</name>
    <message>
        <source>cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GreeterWindow</name>
    <message>
        <source>CN</source>
        <translation type="obsolete">CN</translation>
    </message>
    <message>
        <source>EN</source>
        <translation type="obsolete">EN</translation>
    </message>
</context>
<context>
    <name>GreeterWrapper</name>
    <message>
        <source>failed to start session.</source>
        <translation>impossible de démarrer la session.</translation>
    </message>
</context>
<context>
    <name>IconEdit</name>
    <message>
        <source>Login</source>
        <translation type="obsolete">S&apos;identifier</translation>
    </message>
</context>
<context>
    <name>KeyboardWidget</name>
    <message>
        <source>KeyboardWidget</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LoginWindow</name>
    <message>
        <source>Login</source>
        <translation>S&apos;identifier</translation>
    </message>
    <message>
        <source>logged in</source>
        <translation>connecté</translation>
    </message>
    <message>
        <source>login</source>
        <translation>s&apos;identifier</translation>
    </message>
    <message>
        <source>Password: </source>
        <translation>Mot de passe: </translation>
    </message>
    <message>
        <source>login:</source>
        <translation type="vanished">s&apos;identifier:</translation>
    </message>
    <message>
        <source>Incorrect password, please input again</source>
        <translation type="unfinished">Mot de passe incorrect, veuillez saisir à nouveau</translation>
    </message>
    <message>
        <source>please select the type of authentication</source>
        <translation type="obsolete">veuillez sélectionner le type d&apos;authentification</translation>
    </message>
    <message>
        <source>Incorrect user name, please input again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Retry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Biometric Authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password Authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other Devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>MainWindow</source>
        <translation type="unfinished">Fenêtre principale</translation>
    </message>
</context>
<context>
    <name>PowerManager</name>
    <message>
        <source>suspend</source>
        <translation type="obsolete">suspendre</translation>
    </message>
    <message>
        <source>restart</source>
        <translation type="obsolete">redémarrer</translation>
    </message>
    <message>
        <source>shutdown</source>
        <translation type="obsolete">fermer</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Power Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sleep</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PowerWindow</name>
    <message>
        <source>Goodbye. Would you like to…</source>
        <translation type="obsolete">Au revoir. Voudriez-vous…</translation>
    </message>
    <message>
        <source>Other users are currently logged in to this computer, shutting down now will also close these other sessions.</source>
        <translation type="vanished">D&apos;autres utilisateurs sont actuellement connectés à cet ordinateur, leur fermeture ferme également ces autres sessions.</translation>
    </message>
    <message>
        <source>suspend</source>
        <translation type="vanished">suspendre</translation>
    </message>
    <message>
        <source>hibernate</source>
        <translation type="vanished">hiberner</translation>
    </message>
    <message>
        <source>restart</source>
        <translation type="vanished">redémarrer</translation>
    </message>
    <message>
        <source>shutdown</source>
        <translation type="vanished">fermer</translation>
    </message>
</context>
<context>
    <name>SessionWindow</name>
    <message>
        <source>select the desktop environment</source>
        <translation type="obsolete">sélectionner l&apos;environnement de bureau</translation>
    </message>
    <message>
        <source> (Default)</source>
        <translation type="vanished"> (Défaut)</translation>
    </message>
</context>
<context>
    <name>UserEntry</name>
    <message>
        <source>logged in</source>
        <translation type="vanished">connecté</translation>
    </message>
</context>
<context>
    <name>UsersModel</name>
    <message>
        <source>Guest Session</source>
        <translation>Session d&apos;invité</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>S&apos;identifier</translation>
    </message>
    <message>
        <source>Guest</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
